# Протеинко 🇷🇸

Протеинко се користи за моделовање дистрибуција хемијског састава као и 
физикохемисјксих особина пептида.

---

### О Протеинку

Протеин или пептид је секвенца амино киселина повезаних пептидним везама. Свака 
аминокиселина окарактерисана је сопственим хемијски саставом и последично 
одређеним физикохемијским особинама. 

Помоћу Протеинка можемо моделовати дистрибуцију хемисјког састава пептида и 
на тај начин преставити протеин као скуп једнодимензионих вектора од који сваки 
представља дистрибуцију једног хемијсог елемента или једне физичке или хемијске 
особине. 

Главна особина али и ограничење Протеинка је то што подразумева линеарну или 
близу линеарну тродимензионалну структуру протеина, односно да протеин у 
свом природном окружењу или интеракцијама не заузума комплексну 
глобуларну структуру. 

Протеинко дакле пружа могућност изоловања одређених особина 
линеарних пептида ради упоређивања са другим пептидима или откривања скривених 
законитости у структури или интеракцијама. Најзначајније је то што Протеинко 
омогућава представљање прептида на нумерички начин што отвара могућност 
за коришћење различитих софтвера и алгоритама за манупулацију нумеричким 
подацима.


![plot1](https://raw.githubusercontent.com/stefs304/proteinko/dev/resources/plot1.png)

Протеинко може да моделује следеће особине:
* Хемијски састав (C, H, N, O, S)
* Хидрофобност
* Донорске водоничне везе
* Акцепторске водоничне везе
* Изоелектрични потенцијал
* Ван дер Валсов волумен, тј. запремина

### Инсталација
```bash
pip install proteinko
```

### Употреба

```python
from proteinko import Proteinko

prot = Proteinko()

# Излистај све подржане шеме
prot.schemas

# Моделуј дистрибуцију пептида, по једној од шема
dist = prot.get_dist('ILKEPVHGV', schema='hydropathy')
```
